summaryrefslogtreecommitdiffstats
path: root/Tools/QtBiomeVisualiser/BiomeView.h
diff options
context:
space:
mode:
Diffstat (limited to 'Tools/QtBiomeVisualiser/BiomeView.h')
-rw-r--r--Tools/QtBiomeVisualiser/BiomeView.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/Tools/QtBiomeVisualiser/BiomeView.h b/Tools/QtBiomeVisualiser/BiomeView.h
index 40d8b96ae..9901b8f24 100644
--- a/Tools/QtBiomeVisualiser/BiomeView.h
+++ b/Tools/QtBiomeVisualiser/BiomeView.h
@@ -2,7 +2,7 @@
#include <QWidget>
#include <memory>
-#include "ChunkCache.h"
+#include "RegionCache.h"
#include "ChunkSource.h"
@@ -51,8 +51,8 @@ public slots:
/** Redraw the entire widget area. */
void redraw();
- /** A specified chunk has become available, redraw it. */
- void chunkAvailable(int a_ChunkX, int a_ChunkZ);
+ /** A specified region has become available, redraw it. */
+ void regionAvailable(int a_RegionX, int a_RegionZ);
/** Reloads the current chunk source and redraws the entire workspace. */
void reload();
@@ -62,7 +62,7 @@ protected:
double m_Zoom;
/** Cache for the loaded chunk data. */
- ChunkCache m_Cache;
+ RegionCache m_Cache;
/** The entire view's contents in an offscreen image. */
QImage m_Image;